"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prefetch = prefetch;
exports.prefetchJsonFor = prefetchJsonFor;
exports.waitForServiceWorker = waitForServiceWorker;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

/**
 * Prefetch a URL using the service worker.
 * @param {String} url The URL to prefetch
 */
function prefetch(_x) {
  return _prefetch.apply(this, arguments);
}
/**
 * Prefetches the JSON API results for a given page
 * @param {String} url The page URL.
 */


function _prefetch() {
  _prefetch = (0, _asyncToGenerator2["default"])(
  /*#__PURE__*/
  _regenerator["default"].mark(function _callee(url) {
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return waitForServiceWorker();

          case 2:
            if (!_context.sent) {
              _context.next = 4;
              break;
            }

            navigator.serviceWorker.controller.postMessage({
              action: 'cache-path',
              path: url,
              apiVersion: process.env.RSF_API_VERSION || '1'
            });

          case 4:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _prefetch.apply(this, arguments);
}

function prefetchJsonFor(url) {
  var parsed = new URL(url);
  return prefetch("/api".concat(parsed.pathname).concat(parsed.search));
}
/**
 * Resolves when the service worker has been installed.
 * @private
 */


function waitForServiceWorker() {
  if (!navigator.serviceWorker || !navigator.serviceWorker.ready) {
    return false;
  }

  return new Promise(function (resolve) {
    navigator.serviceWorker.ready.then(function () {
      if (navigator.serviceWorker.controller) {
        return resolve(true);
      }

      navigator.serviceWorker.addEventListener('controllerchange', function () {
        return resolve(true);
      });
    });
  });
}
//# sourceMappingURL=serviceWorker.js.map